Struct XdgActivationTokenV1
pub struct XdgActivationTokenV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
an exported activation handle
An object for setting up a token and receiving a token handle that can be passed as an activation token to another client.
The object is created using the xdg_activation_v1.get_activation_token request. This object should then be populated with the app_id, surface and serial information and committed. The compositor shall then issue a done event with the token. In case the request’s parameters are invalid, the compositor will provide an invalid token.
See also the Request enum for this interface.
Implementations